import * as tslib_1 from "tslib";
import React from 'react';
import { ScrollView } from 'react-native';
import validate from 'validate.js';
var Form = /** @class */ (function (_super) {
    tslib_1.__extends(Form, _super);
    function Form(props) {
        var _this = _super.call(this, props) || this;
        _this.state = {
            fields: props.fields,
            errors: {}
        };
        _this.clearError = _this.clearError.bind(_this);
        _this.getValue = _this.getValue.bind(_this);
        _this.setValue = _this.setValue.bind(_this);
        _this.submit = _this.submit.bind(_this);
        _this.validate = _this.validate.bind(_this);
        _this.reset = _this.reset.bind(_this);
        return _this;
    }
    Form.getDerivedStateFromProps = function (props) {
        if (props.resetOnInitialValueChanged) {
            return {
                fields: props.fields
            };
        }
        return null;
    };
    Form.prototype.render = function () {
        var _a = this.props, children = _a.children, style = _a.style;
        return (<ScrollView keyboardShouldPersistTaps="handled" contentContainerStyle={style}>
        {children({
            fields: this.state.fields,
            setValue: this.setValue,
            submit: this.submit,
            errors: this.state.errors,
            clearError: this.clearError,
            validate: this.validate
        })}
      </ScrollView>);
    };
    Form.prototype.reset = function () {
        this.setState({ fields: this.props.fields });
    };
    Form.prototype.setValue = function (key, value) {
        var _this = this;
        var _a;
        var onChange = this.props.onChange;
        var newVal = typeof key === 'string' ? (_a = {}, _a[key] = value, _a) : key;
        var fields = tslib_1.__assign({}, this.state.fields, newVal);
        this.setState({ fields: fields }, function () {
            if (onChange) {
                onChange(fields, _this.validate, _this.clearError);
            }
        });
    };
    Form.prototype.getValue = function (key) {
        return this.state.fields[key];
    };
    Form.prototype.submit = function () {
        var _this = this;
        var _a = this.props, onSubmit = _a.onSubmit, onError = _a.onError;
        this.validate().then(function (valid) {
            if (valid) {
                if (onSubmit) {
                    onSubmit(_this.state.fields);
                }
            }
            else if (onError) {
                onError(_this.state.errors);
            }
        });
    };
    Form.prototype.validate = function () {
        var _this = this;
        return new Promise(function (resolve) {
            var errors = validate.validate(_this.state.fields, _this.props.validator, {
                fullMessages: false
            });
            _this.setState({ errors: errors || {} });
            resolve(!!!errors);
        });
    };
    Form.prototype.clearError = function (key) {
        var _a;
        var toClear = (_a = {}, _a[key] = undefined, _a);
        this.setState({ errors: tslib_1.__assign({}, this.state.errors, toClear) });
    };
    return Form;
}(React.Component));
export { Form };
//# sourceMappingURL=Form.js.map