import * as tslib_1 from "tslib";
import { withLocaleClass } from '@dokuhero/react-18n-ts-helper';
import { withThemeClass } from '@dokuhero/react-native-theme';
import { ImagePicker as IP, Permissions } from 'expo';
import React from 'react';
import { Image, Text, View } from 'react-native';
import { ButtonGroup } from './ButtonGroup';
var IMAGE_SIZE = 160;
var ImagePicker = /** @class */ (function (_super) {
    tslib_1.__extends(ImagePicker, _super);
    function ImagePicker(props) {
        var _this = _super.call(this, props) || this;
        _this.selectPicture = _this.selectPicture.bind(_this);
        _this.takePicture = _this.takePicture.bind(_this);
        _this.setValue = _this.setValue.bind(_this);
        _this.state = {
            uri: null
        };
        return _this;
    }
    ImagePicker.getDerivedStateFromProps = function (nextProps, prevState) {
        if (nextProps.uri !== prevState.uri) {
            return tslib_1.__assign({}, prevState, { uri: nextProps.uri });
        }
        return prevState;
    };
    ImagePicker.prototype.render = function () {
        var _a = this.props, t = _a.t, _b = _a.theme, color = _b.color, space = _b.space;
        var uri = this.state.uri;
        return (<View>
        <View style={{
            alignItems: 'center',
            paddingTop: space.small,
            paddingHorizontal: space.small
        }}>
          <View style={{
            width: '100%',
            height: IMAGE_SIZE + 2,
            borderWidth: 1,
            borderStyle: 'dotted',
            borderColor: color.lighter,
            alignItems: 'center',
            flexDirection: 'row',
            paddingHorizontal: 10
        }}>
            <View style={{
            flex: 1,
            alignItems: 'center'
        }}>
              {uri ? (<Image source={{ uri: uri }} style={{ width: IMAGE_SIZE, height: IMAGE_SIZE }}/>) : (<Text style={{ color: color.lighter }}>
                  {t('pleaseSelectImage')}
                </Text>)}
            </View>
          </View>
        </View>
        <ButtonGroup buttons={[
            {
                title: t('takePicture'),
                icon: { name: 'camera', type: 'feather' },
                onPress: this.takePicture
            },
            {
                title: t('selectPicture'),
                icon: { name: 'file', type: 'feather' },
                onPress: this.selectPicture
            }
        ]}/>
      </View>);
    };
    /**
     * Select picture from image library
     */
    ImagePicker.prototype.selectPicture = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var result;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, IP.launchImageLibraryAsync({
                            aspect: [IMAGE_SIZE, IMAGE_SIZE],
                            allowsEditing: true,
                            mediaTypes: 'Images'
                        })];
                    case 1:
                        result = _a.sent();
                        if (!!result.cancelled) return [3 /*break*/, 3];
                        return [4 /*yield*/, this.setValue(result.uri)];
                    case 2:
                        _a.sent();
                        _a.label = 3;
                    case 3: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Get picture from camera
     */
    ImagePicker.prototype.takePicture = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var cameraPermission, cameraRollPermission, result;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, Permissions.askAsync(Permissions.CAMERA)];
                    case 1:
                        cameraPermission = _a.sent();
                        return [4 /*yield*/, Permissions.askAsync(Permissions.CAMERA_ROLL)];
                    case 2:
                        cameraRollPermission = _a.sent();
                        if (!(cameraRollPermission.status === 'granted' &&
                            cameraPermission.status === 'granted')) return [3 /*break*/, 5];
                        return [4 /*yield*/, IP.launchCameraAsync({
                                aspect: [IMAGE_SIZE, IMAGE_SIZE],
                                allowsEditing: true
                            })];
                    case 3:
                        result = _a.sent();
                        if (!!result.cancelled) return [3 /*break*/, 5];
                        return [4 /*yield*/, this.setValue(result.uri)];
                    case 4:
                        _a.sent();
                        _a.label = 5;
                    case 5: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Dispay picture
     * @param {string} uri
     */
    ImagePicker.prototype.setValue = function (uri) {
        var onChange = this.props.onChange;
        this.setState({ uri: uri }, function () {
            if (onChange) {
                onChange(uri);
            }
        });
    };
    ImagePicker = tslib_1.__decorate([
        withLocaleClass('common'),
        withThemeClass(),
        tslib_1.__metadata("design:paramtypes", [Object])
    ], ImagePicker);
    return ImagePicker;
}(React.Component));
export { ImagePicker };
//# sourceMappingURL=ImagePicker.js.map