import React from 'react'
import { StyleProp, ViewStyle } from 'react-native'
export declare type FormValidationErrors<T> = { [K in keyof T]: string[] }
export interface FormChildrenProps<T> {
  fields: T
  errors: FormValidationErrors<T>
  setValue(key: keyof T, value?: any): void
  setValue(state: Partial<T>): void
  submit(): void
  clearError(key: keyof T): void
  validate(): void
}
export interface FormProps<T> {
  fields: T
  children: (props: FormChildrenProps<T>) => React.ReactNode
  validator: Partial<Pick<any, keyof T>>
  onSubmit?: (values: T) => void
  onChange?: (
    values: T,
    validate: () => void,
    clearError: (key: keyof T) => void
  ) => void
  onError?: (errors: FormValidationErrors<T>) => void
  style?: StyleProp<ViewStyle>
  resetOnInitialValueChanged?: boolean
}
interface State<T> {
  fields: T
  errors: FormValidationErrors<T> | any
}
export declare class Form<T = {}> extends React.Component<
  FormProps<T>,
  State<T>
> {
  static getDerivedStateFromProps(
    props: FormProps<{}>
  ): Partial<State<{}>> | null
  constructor(props: FormProps<T>)
  render(): JSX.Element
  reset(): void
  setValue(state: {}, val?: any): void
  getValue(key: keyof T): any
  submit(): void
  validate(): Promise<boolean>
  clearError(key: keyof T): void
}
export {}
